#!/usr/bin/env bash
set -e

# URL may end with a tag/commits as fragment
source_repos=(
  "git://git.proxmox.com/git/proxmox-backup.git#tag=v3.3.2"
  "git://git.proxmox.com/git/proxmox.git#commit=619c290cf8e6e99a5a7aa05ffdcf7dd30dea30bd"
  "git://git.proxmox.com/git/proxmox-fuse.git"
  "git://git.proxmox.com/git/pathpatterns.git"
  "git://git.proxmox.com/git/pxar.git"
  "https://github.com/hyperium/h2.git#tag=v0.4.7"
)

rust_version=1.85.1

rpmbuild_sources_dir="$(rpm --eval "%{_sourcedir}")"

pushd "${rpmbuild_sources_dir}"

## Download all proxmox repos
for repo in "${source_repos[@]}"; do
  repo_url=${repo%#*}
  repo_dir=$(basename "$repo_url" .git)
  repo_ref=""
  if [[ "$repo" == *"#"* ]]; then
    repo_ref=${repo##*#}
  fi

  git clone "${repo_url}" "${repo_dir}"

  # Checkout tag/commit, if specified
  if [ -n "${repo_ref}" ]; then
    pushd "${repo_dir}"
    git -c advice.detachedHead=false checkout "${repo_ref#*=}"
    popd
  fi
done

## Apply patches

# Delete cargo registry overrides (hardcoded for Debian...)
rm -f proxmox-backup/.cargo/config.toml

apply_patch() {
  repo=$1
  patch=$2

  pushd "${repo}"
  echo "Applying patch to ${repo}: ${patch}"
  patch --forward --strip=1 --input="${rpmbuild_sources_dir}/${patch}"
  popd
}

apply_patch h2 0003-cargo-downgrade-http-to-0.2.12.patch
apply_patch proxmox 0005-sys-use-correct-pointer-type-for-mkdtemp-return-valu.patch
apply_patch proxmox-backup 0001-re-route-dependencies-not-available-on-crates.io-to-.patch
apply_patch proxmox-backup 0002-docs-drop-all-but-client-man-pages.patch
apply_patch proxmox-backup 0004-cargo-use-local-patched-h2-dependency.patch
apply_patch proxmox-fuse 1001-remove-noflush-attr.patch

## End of patches
popd

## Install Rust
curl -sSf https://sh.rustup.rs | sh -s -- --profile default -y --default-toolchain "${rust_version}"
